abacusai.document_retriever_version — AbacusAI documentation

# `abacusai.document_retriever_version`

## Module Contents

### Classes

`DocumentRetrieverVersion` | A version of document retriever.

class abacusai.document_retriever_version.DocumentRetrieverVersion(client, documentRetrieverId=None, documentRetrieverVersion=None, createdAt=None, status=None, featureGroupVersion=None, error=None, numberOfChunks=None, embeddingFileSize=None, resolvedConfig={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A version of document retriever.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - documentRetrieverId (str) – The unique identifier of the vector store.

    - documentRetrieverVersion (str) – The unique identifier of the vector store version.

    - createdAt (str) – When the vector store was created.

    - status (str) – The status of creating vector store version.

    - featureGroupVersion (str) – The unique identifier of the feature group version at which the vector store version is created.

    - error (str) – The error message when it failed to create the document retriever version.

    - numberOfChunks (int) – The number of chunks for the document retriever.

    - embeddingFileSize (int) – The size of embedding file for the document retriever.

    - resolvedConfig (DocumentRetrieverConfig) – The resolved configurations, such as default settings, for indexing documents.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  refresh()

    Calls describe and refreshes the current object’s fields

    Returns:

      The current object

    Return type:

      DocumentRetrieverVersion

  describe()

    Describe a document retriever version.

    Parameters:

      document_retriever_version (str) – A unique string identifier associated with the document retriever version.

    Returns:

      The document retriever version object.

    Return type:

      DocumentRetrieverVersion

  wait_for_results(timeout=3600)

    A waiting call until document retriever version is complete.

    Parameters:

      timeout (int, optional) – The waiting time given to the call to finish, if it doesn’t finish by the allocated time, the call is said to be timed out.

  wait_until_ready(timeout=3600)

    A waiting call until the document retriever version is ready.

    Parameters:

      timeout (int, optional) – The waiting time given to the call to finish, if it doesn’t finish by the allocated time, the call is said to be timed out.

  get_status()

    Gets the status of the document retriever version.

    Returns:

      A string describing the status of a document retriever version (pending, complete, etc.).

    Return type:

      str